# MockWalkers

![Corridor demo gif](https://github.com/matiassimon/mockwalkers/raw/develop/examples/corridor.gif)

## Desciption

A walkers dynamic simulation library.

This project originated as our final project during the 9th Workshop on Collaborative Scientific Software Development and Management of Open Source Scientific Packages, held at the International Centre for Theoretical Physics (ICTP) in the picturesque city of Trieste, Italy.

## Installation

```
pip install mockwalkers
```

## Authors

David, Jimoh, Matias and Alouette

## License

See LICENCE file